from basic import BasicEventTracker
from tap import TapTracker
from transform import TransformationTracker


# Map of gesture type to tracker type
_tracker_types = {}


def _register_tracker(tracker_type):
    tracker_type.gesture_types = \
            [gesture._type for gesture in tracker_type.supported_gestures]

    for gesture_type in tracker_type.gesture_types:
        if gesture_type in _tracker_types:
            raise ValueError('Gesture type "%s" is already registered to '
                                'tracker type "%s".' % (gesture_type,
                                _tracker_types[gesture_type].__name__))

        _tracker_types[gesture_type] = tracker_type


def create_tracker(gesture_type, widget):
    if gesture_type not in _tracker_types:
        raise KeyError('No tracker type registered for gesture type "%s".'
                        % gesture_type)

    return _tracker_types[gesture_type](widget)


_register_tracker(BasicEventTracker)
_register_tracker(TapTracker)
_register_tracker(TransformationTracker)
